Changelog — appypi dev documentation

### Navigation

- index
- previous |
- appypi dev documentation »

# Changelog

## 0.1 (2012-11-11)

- Initial release

### Table Of Contents

- Changelog
  - 0.1 (2012-11-11)

#### Previous topic

Some technical details

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- previous |
- appypi dev documentation »

© Copyright 2012, Stéphane Péchard. Created using Sphinx 1.1.3.